/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PagedDTOCommentDTOAsResponse } from "../../definitions/PagedDTOCommentDTOAsResponse";
import { ErrorResponseAsResponse } from "../../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { CommentCreateDTO } from "../../definitions/CommentCreateDTO";
import { CommentDTOAsResponse } from "../../definitions/CommentDTOAsResponse";
import { PagedDTOAttachmentDTOAsResponse } from "../../definitions/PagedDTOAttachmentDTOAsResponse";
export interface GetRequestCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the customer request whose comments will be retrieved.
     */
    issueIdOrKey: string;
    /**
     * Specifies whether to return public comments or not. Default: true.
     */
    public?: boolean;
    /**
     * Specifies whether to return internal comments or not. Default: true.
     */
    internal?: boolean;
    /**
  * A multi-value parameter indicating which properties of the comment to expand:
  
   *  `attachment` returns the attachment details, if any, for each comment. (If you want to get all attachments for a request, use [servicedeskapi/request/\{issueIdOrKey\}/attachment](#api-request-issueIdOrKey-attachment-get).)
   *  `renderedBody` (Experimental) returns the rendered body in HTML format (in addition to the raw body) for each comment.
  */
    expand?: Array<string>;
    /**
     * The starting index of the returned comments. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of comments to return per page. Default: 50. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetRequestCommentsResponseOKType = PagedDTOCommentDTOAsResponse;
export interface GetRequestCommentsResponseOK extends GetRequestCommentsResponseOKType {
}
declare type GetRequestCommentsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetRequestCommentsResponseError extends GetRequestCommentsResponseErrorType {
}
export interface CreateRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the customer request to which the comment will be added.
     */
    issueIdOrKey: string;
    body: CommentCreateDTO;
}
declare type CreateRequestCommentResponseOKType = CommentDTOAsResponse;
export interface CreateRequestCommentResponseOK extends CreateRequestCommentResponseOKType {
}
declare type CreateRequestCommentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CreateRequestCommentResponseError extends CreateRequestCommentResponseErrorType {
}
export interface GetRequestCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the customer request that contains the comment.
     */
    issueIdOrKey: string;
    /**
     * The ID of the comment to retrieve.
     */
    commentId: number;
    /**
  * A multi-value parameter indicating which properties of the comment to expand:
  
   *  `attachment` returns the attachment details, if any, for the comment. (If you want to get all attachments for a request, use [servicedeskapi/request/\{issueIdOrKey\}/attachment](#api-request-issueIdOrKey-attachment-get).)
   *  `renderedBody` (Experimental) returns the rendered body in HTML format (in addition to the raw body) of the comment.
  */
    expand?: Array<string>;
}
declare type GetRequestCommentResponseOKType = CommentDTOAsResponse;
export interface GetRequestCommentResponseOK extends GetRequestCommentResponseOKType {
}
declare type GetRequestCommentResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetRequestCommentResponseError extends GetRequestCommentResponseErrorType {
}
export interface GetRequestCommentAttachmentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the customer request that contains the comment.
     */
    issueIdOrKey: string;
    /**
     * The ID of the comment.
     */
    commentId: number;
    /**
     * The starting index of the returned comments. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of comments to return per page. Default: 50. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetRequestCommentAttachmentsResponseOKType = PagedDTOAttachmentDTOAsResponse;
export interface GetRequestCommentAttachmentsResponseOK extends GetRequestCommentAttachmentsResponseOKType {
}
declare type GetRequestCommentAttachmentsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetRequestCommentAttachmentsResponseError extends GetRequestCommentAttachmentsResponseErrorType {
}
export {};
//# sourceMappingURL=comment.d.ts.map