/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PagedDTOQueueDTOAsResponse } from "../../definitions/PagedDTOQueueDTOAsResponse";
import { ErrorResponseAsResponse } from "../../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { QueueDTOAsResponse } from "../../definitions/QueueDTOAsResponse";
import { PagedDTOIssueBeanAsResponse } from "../../definitions/PagedDTOIssueBeanAsResponse";
export interface GetServicedeskQueuesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID of the service desk whose queues will be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * Specifies whether to include each queue's customer request (issue) count in the response.
     */
    includeCount?: boolean;
    /**
     * The starting index of the returned objects. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of items to return per page. Default: 50. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetServicedeskQueuesResponseOKType = PagedDTOQueueDTOAsResponse;
export interface GetServicedeskQueuesResponseOK extends GetServicedeskQueuesResponseOKType {
}
declare type GetServicedeskQueuesResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskQueuesResponseError extends GetServicedeskQueuesResponseErrorType {
}
export interface GetServicedeskQueueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * ID of the service desk whose queues will be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * ID of the required queue.
     */
    queueId: number;
    /**
     * Specifies whether to include each queue's customer request (issue) count in the response.
     */
    includeCount?: boolean;
}
declare type GetServicedeskQueueResponseOKType = QueueDTOAsResponse;
export interface GetServicedeskQueueResponseOK extends GetServicedeskQueueResponseOKType {
}
declare type GetServicedeskQueueResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskQueueResponseError extends GetServicedeskQueueResponseErrorType {
}
export interface GetServicedeskIssuesInQueueRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk containing the queue to be queried. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * The ID of the queue whose customer requests will be returned.
     */
    queueId: number;
    /**
     * The starting index of the returned objects. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of items to return per page. Default: 50. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetServicedeskIssuesInQueueResponseOKType = PagedDTOIssueBeanAsResponse;
export interface GetServicedeskIssuesInQueueResponseOK extends GetServicedeskIssuesInQueueResponseOKType {
}
declare type GetServicedeskIssuesInQueueResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskIssuesInQueueResponseError extends GetServicedeskIssuesInQueueResponseErrorType {
}
export {};
//# sourceMappingURL=queue.d.ts.map