/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PagedDTORequestTypeDTOAsResponse } from "../../../definitions/PagedDTORequestTypeDTOAsResponse";
import { ErrorResponseAsResponse } from "../../../definitions/ErrorResponseAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { RequestTypeCreateDTO } from "../../../definitions/RequestTypeCreateDTO";
import { RequestTypeDTOAsResponse } from "../../../definitions/RequestTypeDTOAsResponse";
import { CustomerRequestCreateMetaDTOAsResponse } from "../../../definitions/CustomerRequestCreateMetaDTOAsResponse";
import { PagedDTORequestTypeGroupDTOAsResponse } from "../../../definitions/PagedDTORequestTypeGroupDTOAsResponse";
export interface GetServicedeskRequestTypesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk whose customer request types are to be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * Filters results to those in a customer request type group.
     */
    groupId?: number;
    expand?: Array<string>;
    /**
     * The string to be used to filter the results.
     */
    searchQuery?: string;
    /**
     * The starting index of the returned objects. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of items to return per page. Default: 100. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetServicedeskRequestTypesResponseOKType = PagedDTORequestTypeDTOAsResponse;
export interface GetServicedeskRequestTypesResponseOK extends GetServicedeskRequestTypesResponseOKType {
}
declare type GetServicedeskRequestTypesResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskRequestTypesResponseError extends GetServicedeskRequestTypesResponseErrorType {
}
export interface CreateServicedeskRequestTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk where the customer request type is to be created. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    body: RequestTypeCreateDTO;
}
declare type CreateServicedeskRequestTypeResponseOKType = RequestTypeDTOAsResponse;
export interface CreateServicedeskRequestTypeResponseOK extends CreateServicedeskRequestTypeResponseOKType {
}
declare type CreateServicedeskRequestTypeResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface CreateServicedeskRequestTypeResponseError extends CreateServicedeskRequestTypeResponseErrorType {
}
export interface GetServicedeskRequestTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk whose customer request type is to be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * The ID of the customer request type to be returned.
     */
    requestTypeId: number;
    expand?: Array<string>;
}
declare type GetServicedeskRequestTypeResponseOKType = RequestTypeDTOAsResponse;
export interface GetServicedeskRequestTypeResponseOK extends GetServicedeskRequestTypeResponseOKType {
}
declare type GetServicedeskRequestTypeResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskRequestTypeResponseError extends GetServicedeskRequestTypeResponseErrorType {
}
export interface DeleteServicedeskRequestTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or [project identifier](#project-identifiers) of the service desk.
     */
    serviceDeskId: string;
    /**
     * The ID of the request type.
     */
    requestTypeId: number;
}
export declare type DeleteServicedeskRequestTypeResponseOK = undefined;
declare type DeleteServicedeskRequestTypeResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface DeleteServicedeskRequestTypeResponseError extends DeleteServicedeskRequestTypeResponseErrorType {
}
export interface GetServicedeskRequestTypeFieldsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk containing the request types whose fields are to be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * The ID of the request types whose fields are to be returned.
     */
    requestTypeId: number;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts `hiddenFields` that returns hidden fields associated with the request type.
     */
    expand?: Array<string>;
}
declare type GetServicedeskRequestTypeFieldsResponseOKType = CustomerRequestCreateMetaDTOAsResponse;
export interface GetServicedeskRequestTypeFieldsResponseOK extends GetServicedeskRequestTypeFieldsResponseOKType {
}
declare type GetServicedeskRequestTypeFieldsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskRequestTypeFieldsResponseError extends GetServicedeskRequestTypeFieldsResponseErrorType {
}
export interface GetServicedeskRequestTypeGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the service desk whose customer request type groups are to be returned. This can alternatively be a [project identifier.](#project-identifiers)
     */
    serviceDeskId: string;
    /**
     * The starting index of the returned objects. Base index: 0. See the [Pagination](#pagination) section for more details.
     */
    start?: number;
    /**
     * The maximum number of items to return per page. Default: 100. See the [Pagination](#pagination) section for more details.
     */
    limit?: number;
}
declare type GetServicedeskRequestTypeGroupsResponseOKType = PagedDTORequestTypeGroupDTOAsResponse;
export interface GetServicedeskRequestTypeGroupsResponseOK extends GetServicedeskRequestTypeGroupsResponseOKType {
}
declare type GetServicedeskRequestTypeGroupsResponseErrorType = ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse & ErrorResponseAsResponse;
export interface GetServicedeskRequestTypeGroupsResponseError extends GetServicedeskRequestTypeGroupsResponseErrorType {
}
export {};
//# sourceMappingURL=type.d.ts.map